@@ -1,4 +1,6 @@
 
+from typing import Optional
+
 import cadquery as cq
 from paramak import Shape
 
@@ -7,19 +9,19 @@ class RotateCircleShape(Shape):
     """Rotates a circular 3d CadQuery solid from a central point and a radius
 
     Args:
-        radius (float): radius of the shape
-        rotation_angle (float, optional): The rotation_angle to use when
-            revolving the solid (degrees). Defaults to 360.0.
-        stp_filename (str, optional):  Defaults to "RotateCircleShape.stp".
-        stl_filename (str, optional):  Defaults to "RotateCircleShape.stl".
+        radius: radius of the shape
+        rotation_angle: The rotation_angle to use when revolving the solid
+            (degrees). Defaults to 360.0.
+        stp_filename:  Defaults to "RotateCircleShape.stp".
+        stl_filename:  Defaults to "RotateCircleShape.stl".
     """
 
     def __init__(
         self,
-        radius,
-        rotation_angle=360.0,
-        stp_filename="RotateCircleShape.stp",
-        stl_filename="RotateCircleShape.stl",
+        radius: float,
+        rotation_angle: Optional[float] = 360.0,
+        stp_filename: Optional[str] = "RotateCircleShape.stp",
+        stl_filename: Optional[str] = "RotateCircleShape.stl",
         **kwargs
     ):
 
