@@ -1,4 +1,6 @@
 
+from typing import Optional
+
 from paramak import RotateMixedShape
 
 
@@ -6,17 +8,17 @@ class RotateSplineShape(RotateMixedShape):
     """Rotates a 3d CadQuery solid from points connected with splines.
 
     Args:
-        rotation_angle (float, optional): The rotation_angle to use when
-            revolving the solid (degrees). Defaults to 360.0.
-        stp_filename (str, optional): Defaults to "RotateSplineShape.stp".
-        stl_filename (str, optional): Defaults to "RotateSplineShape.stl".
+        rotation_angle: The rotation_angle to use when revolving the solid.
+            Defaults to 360.0.
+        stp_filename: Defaults to "RotateSplineShape.stp".
+        stl_filename: Defaults to "RotateSplineShape.stl".
     """
 
     def __init__(
         self,
-        rotation_angle=360,
-        stp_filename="RotateSplineShape.stp",
-        stl_filename="RotateSplineShape.stl",
+        rotation_angle: Optional[float] = 360,
+        stp_filename: Optional[str] = "RotateSplineShape.stp",
+        stl_filename: Optional[str] = "RotateSplineShape.stl",
         **kwargs
     ):
 
