@@ -1,4 +1,6 @@
 
+from typing import Optional, List, Tuple
+
 import cadquery as cq
 from paramak import Shape
 
@@ -9,30 +11,29 @@ class SweepCircleShape(Shape):
     the solid may occur.
 
     Args:
-        radius (float): Radius of 2D circle to be swept.
-        path_points (list of tuples each containing X (float), Z (float)): A
-            list of XY, YZ or XZ coordinates connected by spline connections
-            which define the path along which the 2D shape is swept.
-        workplane (str, optional): Workplane in which the circle to be swept
+        radius: Radius of 2D circle to be swept.
+        path_points: A list of XY, YZ or XZ coordinates connected by spline
+            connections which define the path along which the 2D shape is swept
+        workplane: Workplane in which the circle to be swept
             is defined. Defaults to "XY".
-        path_workplane (str, optional): Workplane in which the spline path is
+        path_workplane: Workplane in which the spline path is
             defined. Defaults to "XZ".
-        stp_filename (str, optional): Defaults to "SweepCircleShape.stp".
-        stl_filename (str, optional): Defaults to "SweepCircleShape.stl".
-        force_cross_section (bool, optional): If True, cross-section of solid
-            is forced to be shape defined by points in workplane at each
-            path_point. Defaults to False.
+        stp_filename: Defaults to "SweepCircleShape.stp".
+        stl_filename: Defaults to "SweepCircleShape.stl".
+        force_cross_section: If True, cross-section of solid is forced to be
+            shape defined by points in workplane at each path_point. Defaults
+            to False.
     """
 
     def __init__(
         self,
-        radius,
-        path_points,
-        workplane="XY",
-        path_workplane="XZ",
-        stp_filename="SweepCircleShape.stp",
-        stl_filename="SweepCircleShape.stl",
-        force_cross_section=False,
+        radius: float,
+        path_points: List[Tuple[float, float]],
+        workplane: Optional[str] = "XY",
+        path_workplane: Optional[str] = "XZ",
+        stp_filename: Optional[str] = "SweepCircleShape.stp",
+        stl_filename: Optional[str] = "SweepCircleShape.stl",
+        force_cross_section: Optional[bool] = False,
         **kwargs
     ):
 
@@ -95,19 +96,30 @@ class SweepCircleShape(Shape):
         if self.workplane in ["XZ", "YX", "ZY"]:
             factor *= -1
 
+        wires = []
         if self.force_cross_section:
             wire = cq.Workplane(self.workplane).center(0, 0)
             for point in self.path_points[:-1]:
-                wire = wire.workplane(offset=point[1] * factor).\
-                    center(point[0], 0).\
-                    circle(self.radius).\
-                    center(-point[0], 0).\
-                    workplane(offset=-point[1] * factor)
+                wire = (
+                    wire.workplane(offset=point[1] * factor)
+                    .center(point[0], 0)
+                    .circle(self.radius)
+                )
 
-            self.wire = wire
+                wires.append(wire)
 
-            solid = wire.workplane(offset=self.path_points[-1][1] * factor).center(
-                self.path_points[-1][0], 0).circle(self.radius).sweep(path, multisection=True)
+                wire = (
+                    wire.center(-point[0], 0)
+                    .workplane(offset=-point[1] * factor)
+                )
+
+            self.wire = wires
+
+            solid = wire.workplane(
+                offset=self.path_points[-1][1] * factor) \
+                .center(self.path_points[-1][0], 0) \
+                .circle(self.radius) \
+                .sweep(path, multisection=True)
 
         else:
 
