@@ -1,11 +1,11 @@
 
 import json
-from collections import Iterable
+from collections.abc import Iterable
 from pathlib import Path
+from typing import Optional, Tuple, List
 
 import cadquery as cq
 import matplotlib.pyplot as plt
-import plotly.graph_objects as go
 from cadquery import exporters
 
 import paramak
@@ -82,11 +82,11 @@ class Reactor:
         (excluding the plasma)"""
         values = []
         for shape_or_component in self.shapes_and_components:
-            if isinstance(
+            if not isinstance(
                 shape_or_component,
                 (paramak.Plasma,
                  paramak.PlasmaFromPoints,
-                 paramak.PlasmaBoundaries)) is False:
+                 paramak.PlasmaBoundaries)):
                 values.append(shape_or_component.material_tag)
         return values
 
@@ -97,8 +97,8 @@ class Reactor:
     @property
     def tet_meshes(self):
         values = []
-        for shape_or_componet in self.shapes_and_components:
-            values.append(shape_or_componet.tet_mesh)
+        for shape_or_component in self.shapes_and_components:
+            values.append(shape_or_component.tet_mesh)
         return values
 
     @tet_meshes.setter
@@ -141,8 +141,7 @@ class Reactor:
     @property
     def solid(self):
         """This combines all the parametric shapes and compents in the reactor
-        object and rotates the viewing angle so that .solid operations in
-        jupyter notebook.
+        object.
         """
 
         list_of_cq_vals = []
@@ -150,7 +149,7 @@ class Reactor:
         for shape_or_compound in self.shapes_and_components:
             if isinstance(
                     shape_or_compound.solid,
-                    cq.occ_impl.shapes.Compound):
+                    (cq.occ_impl.shapes.Shape, cq.occ_impl.shapes.Compound)):
                 for solid in shape_or_compound.solid.Solids():
                     list_of_cq_vals.append(solid)
             else:
@@ -158,26 +157,24 @@ class Reactor:
 
         compound = cq.Compound.makeCompound(list_of_cq_vals)
 
-        compound = compound.rotate(
-            startVector=(0, 1, 0), endVector=(0, 0, 1), angleDegrees=180
-        )
         return compound
 
-    @solid.setter
+    @ solid.setter
     def solid(self, value):
         self._solid = value
 
-    def neutronics_description(self, include_plasma: bool = False,
-                               include_graveyard: bool = True
-                               ):
+    def neutronics_description(
+            self,
+            include_plasma: Optional[bool] = False,
+            include_graveyard: Optional[bool] = True) -> dict:
         """A description of the reactor containing material tags, stp filenames,
-        and tet mesh instructions. This is used for neutronics simulations which
-        require linkage between volumes, materials and identification of which
-        volumes to tet mesh. The plasma geometry is not included by default as
-        it is typically not included in neutronics simulations. The reason for
-        this is that the low number density results in minimal interaction with
-        neutrons. However, it can be added if the include_plasma argument is set
-        to True.
+        and tet mesh instructions. This is used for neutronics simulations
+        which require linkage between volumes, materials and identification of
+        which volumes to tet mesh. The plasma geometry is not included by
+        default as it is typically not included in neutronics simulations. The
+        reason for this is that the low number density results in minimal
+        interaction with neutrons. However, it can be added if the
+        include_plasma argument is set to True.
 
         Returns:
             dictionary: a dictionary of materials and filenames for the reactor
@@ -220,9 +217,9 @@ class Reactor:
 
     def export_neutronics_description(
             self,
-            filename: str = "manifest.json",
-            include_plasma: bool = False,
-            include_graveyard: bool = True) -> str:
+            filename: Optional[str] = "manifest.json",
+            include_plasma: Optional[bool] = False,
+            include_graveyard: Optional[bool] = True) -> str:
         """
         Saves Reactor.neutronics_description to a json file. The resulting json
         file contains a list of dictionaries. Each dictionary entry comprises
@@ -271,9 +268,9 @@ class Reactor:
 
     def export_stp(
             self,
-            output_folder: str = "",
-            graveyard_offset: float = 100,
-            mode: str = 'solid') -> list:
+            output_folder: Optional[str] = "",
+            graveyard_offset: Optional[float] = 100,
+            mode: Optional[str] = 'solid') -> List[str]:
         """Writes stp files (CAD geometry) for each Shape object in the reactor
         and the graveyard.
 
@@ -311,7 +308,7 @@ class Reactor:
             )
 
         # creates a graveyard (bounding shell volume) which is needed for
-        # nuetronics simulations
+        # neutronics simulations
         self.make_graveyard(graveyard_offset=graveyard_offset)
         filenames.append(
             str(Path(output_folder) / Path(self.graveyard.stp_filename)))
@@ -321,17 +318,22 @@ class Reactor:
 
         return filenames
 
-    def export_stl(self, output_folder: str = "",
-                   tolerance: float = 0.001) -> list:
+    def export_stl(
+            self,
+            output_folder: Optional[str] = "",
+            graveyard_offset: Optional[float] = 100,
+            tolerance: Optional[float] = 0.001) -> List[str]:
         """Writes stl files (CAD geometry) for each Shape object in the reactor
 
-        :param output_folder: the folder for saving the stp files to
-        :type output_folder: str
-        :param tolerance: the precision of the faceting
-        :type tolerance: float
+        Args:
+            output_folder (str): the folder for saving the stl files to
+            graveyard_offset (float, optional): the offset between the largest
+                edge of the geometry and inner bounding shell created. Defaults
+                to 100.
+            tolerance (float):  the precision of the faceting
 
-        :return: a list of stl filenames created
-        :rtype: list
+        Returns:
+            list: a list of stl filenames created
         """
 
         if len(self.stl_filenames) != len(set(self.stl_filenames)):
@@ -359,8 +361,8 @@ class Reactor:
                 tolerance)
 
         # creates a graveyard (bounding shell volume) which is needed for
-        # nuetronics simulations
-        self.make_graveyard()
+        # neutronics simulations
+        self.make_graveyard(graveyard_offset=graveyard_offset)
         filenames.append(
             str(Path(output_folder) / Path(self.graveyard.stl_filename)))
         self.graveyard.export_stl(
@@ -373,10 +375,10 @@ class Reactor:
 
     def export_h5m(
             self,
-            filename: str = 'dagmc.h5m',
-            skip_graveyard: bool = False,
-            tolerance: float = 0.001,
-            graveyard_offset: float = 100) -> str:
+            filename: Optional[str] = 'dagmc.h5m',
+            skip_graveyard: Optional[bool] = False,
+            tolerance: Optional[float] = 0.001,
+            graveyard_offset: Optional[float] = 100) -> str:
         """Converts stl files into DAGMC compatible h5m file using PyMOAB. The
         DAGMC file produced has not been imprinted and merged unlike the other
         supported method which uses Trelis to produce an imprinted and merged
@@ -446,7 +448,9 @@ class Reactor:
 
         return str(path_filename)
 
-    def export_physical_groups(self, output_folder: str = "") -> list:
+    def export_physical_groups(
+            self,
+            output_folder: Optional[str] = "") -> List[str]:
         """Exports several JSON files containing a look up table which is
         useful for identifying faces and volumes. The output file names are
         generated from .stp_filename properties.
@@ -474,13 +478,50 @@ class Reactor:
                 Path(output_folder) / Path(entry.stp_filename))
         return filenames
 
-    def export_svg(self, filename: str = 'reactor.svg') -> str:
+    def export_svg(
+            self,
+            filename: Optional[str] = 'reactor.svg',
+            projectionDir: Tuple[float, float, float] = (-1.75, 1.1, 5),
+            width: Optional[float] = 1000,
+            height: Optional[float] = 800,
+            marginLeft: Optional[float] = 120,
+            marginTop: Optional[float] = 100,
+            strokeWidth: Optional[float] = None,
+            strokeColor: Optional[Tuple[int, int, int]] = (0, 0, 0),
+            hiddenColor: Optional[Tuple[int, int, int]] = (100, 100, 100),
+            showHidden: Optional[bool] = True,
+            showAxes: Optional[bool] = False) -> str:
         """Exports an svg file for the Reactor.solid. If the filename provided
         doesn't end with .svg it will be added.
 
         Args:
-            filename (str): the filename of the svg file to be exported.
-                Defaults to "reactor.svg".
+            filename: the filename of the svg file to be exported. Defaults to
+                "reactor.svg".
+            projectionDir: The direction vector to view the geometry from
+                (x, y, z). Defaults to (-1.75, 1.1, 5)
+            width: the width of the svg image produced in pixels. Defaults to
+                1000
+            height: the height of the svg image produced in pixels. Defaults to
+                800
+            marginLeft: the number of pixels between the left edge of the image
+                and the start of the geometry.
+            marginTop: the number of pixels between the top edge of the image
+                and the start of the geometry.
+            strokeWidth: the width of the lines used to draw the geometry.
+                Defaults to None which automatically selects an suitable width.
+            strokeColor: the color of the lines used to draw the geometry in
+                RGB format with each value between 0 and 255. Defaults to
+                (0, 0, 0) which is black.
+            hiddenColor: the color of the lines used to draw the geometry in
+                RGB format with each value between 0 and 255. Defaults to
+               (100, 100, 100) which is light grey.
+            showHidden: If the edges obscured by geometry should be included in
+                the diagram. Defaults to True.
+            showAxes: If the x, y, z axis should be included in the image.
+                Defaults to False.
+
+        Returns:
+            str: the svg filename created
         """
 
         path_filename = Path(filename)
@@ -490,16 +531,32 @@ class Reactor:
 
         path_filename.parents[0].mkdir(parents=True, exist_ok=True)
 
-        with open(path_filename, "w") as out_file:
-            exporters.exportShape(self.solid, "SVG", out_file)
+        opt = {
+            "width": width,
+            "height": height,
+            "marginLeft": marginLeft,
+            "marginTop": marginTop,
+            "showAxes": showAxes,
+            "projectionDir": projectionDir,
+            "strokeColor": strokeColor,
+            "hiddenColor": hiddenColor,
+            "showHidden": showHidden
+        }
+
+        if strokeWidth is not None:
+            opt["strokeWidth"] = strokeWidth
+
+        exporters.export(self.solid, str(path_filename), exportType='SVG',
+                         opt=opt)
+
         print("Saved file as ", path_filename)
 
         return str(path_filename)
 
     def export_graveyard(
             self,
-            graveyard_offset: float = 100,
-            filename: str = "Graveyard.stp"):
+            graveyard_offset: Optional[float] = 100,
+            filename: Optional[str] = "Graveyard.stp") -> str:
         """Writes an stp file (CAD geometry) for the reactor graveyard. This
         is needed for DAGMC simulations. This method also calls
         Reactor.make_graveyard with the offset.
@@ -519,7 +576,9 @@ class Reactor:
 
         return new_filename
 
-    def make_graveyard(self, graveyard_offset: float = 100):
+    def make_graveyard(
+            self,
+            graveyard_offset: Optional[float] = 100) -> paramak.Shape:
         """Creates a graveyard volume (bounding box) that encapsulates all
         volumes. This is required by DAGMC when performing neutronics
         simulations.
@@ -554,11 +613,11 @@ class Reactor:
 
     def export_2d_image(
             self,
-            filename="2d_slice.png",
-            xmin: float = 0.0,
-            xmax: float = 900.0,
-            ymin: float = -600.0,
-            ymax: float = 600.0) -> str:
+            filename: Optional[str] = "2d_slice.png",
+            xmin: Optional[float] = 0.0,
+            xmax: Optional[float] = 900.0,
+            ymin: Optional[float] = -600.0,
+            ymax: Optional[float] = 600.0) -> str:
         """Creates a 2D slice image (png) of the reactor.
 
         Args:
@@ -594,35 +653,45 @@ class Reactor:
 
         return str(path_filename)
 
-    def export_html(self, filename="reactor.html"):
+    def export_html(
+            self,
+            filename: Optional[str] = "reactor.html",
+            view_plane: Optional[str] = 'RZ'):
         """Creates a html graph representation of the points for the Shape
-        objects that make up the reactor. Note, If filename provided doesn't end
-        with .html then it will be appended.
+        objects that make up the reactor. Shapes are colored by their .color
+        property. Shapes are also labelled by their .name. If filename provided
+        doesn't end with .html then .html will be added. Viewed from the XZ
+        plane
 
         Args:
-            filename (str): the filename to save the html graph
-
+            filename: the filename used to save the html graph. Defaults to
+                reactor.html
+            view_plane: The axis to view the points and faceted edges from. The
+                options are 'XZ', 'XY', 'YZ', 'YX', 'ZY', 'ZX', 'RZ'. Defaults
+                to 'RZ'.
         Returns:
-            plotly figure: figure object
+            plotly.Figure(): figure object
         """
 
-        path_filename = Path(filename)
+        # accesses the Shape wires for each Shape and builds up a list of
+        # traces
+        all_wires = []
+        for entry in self.shapes_and_components:
+            if not isinstance(entry.wire, list):
+                list_of_wires = [entry.wire]
+            else:
+                list_of_wires = entry.wire
+            all_wires = all_wires + list_of_wires
 
-        if path_filename.suffix != ".html":
-            path_filename = path_filename.with_suffix(".html")
-
-        path_filename.parents[0].mkdir(parents=True, exist_ok=True)
-
-        fig = go.Figure()
-        fig.update_layout(
-            {"title": "coordinates of components", "hovermode": "closest"}
+        fig = paramak.utils.export_wire_to_html(
+            wires=all_wires,
+            filename=filename,
+            view_plane=view_plane,
+            facet_splines=True,
+            facet_circles=True,
+            tolerance=1e-3,
+            title="coordinates of the " + self.__class__.__name__ +
+            " reactor, viewed from the " + view_plane + " plane",
         )
 
-        # accesses the Shape traces for each Shape and adds them to the figure
-        for entry in self.shapes_and_components:
-            fig.add_trace(entry._trace())
-
-        fig.write_html(str(path_filename))
-        print("Exported html graph to ", str(path_filename))
-
         return fig
